# This file was auto-generated by Fern from our API Definition.

import typing

from .conversation_history_transcript_other_tools_result_common_model import (
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
)
from .conversation_history_transcript_system_tool_result_common_model import (
    ConversationHistoryTranscriptSystemToolResultCommonModel,
)

ConversationHistoryTranscriptCommonModelInputToolResultsItem = typing.Union[
    ConversationHistoryTranscriptOtherToolsResultCommonModel, ConversationHistoryTranscriptSystemToolResultCommonModel
]
