# This file was auto-generated by Fern from our API Definition.

import typing

MetricType = typing.Union[
    typing.Literal[
        "credits", "minutes_used", "request_count", "ttfb_avg", "ttfb_p95", "fiat_units_spent", "concurrency"
    ],
    typing.Any,
]
